@@ -15,8 +15,8 @@ class RelationalSchema:
         return [t.data for t in self.tables.values()]
 
     def rename_table(self, current_name, new_name):
-        current_fk = f"{current_name}_id"
-        new_fk = f"{new_name}_id"
+        current_fk = f"{current_name}.__id__"
+        new_fk = f"{new_name}.__id__"
         for k, t in self.tables.items():
             if k == current_name:
                 t.rename(new_name)
