@@ -6,7 +6,7 @@ class Tabulator:
     def __init__(self, docs, name, foreign_keys):
         self._docs = docs
         self.name = name
-        self.primary_key = f"{self.name}_id"
+        self.primary_key = f"{self.name}.__id__"
         self.foreign_keys = foreign_keys
         self.all_keys = [self.primary_key] + self.foreign_keys
         self._insert_index()
